@@ -18,7 +18,8 @@ def current( redis_connection , list_key ):
 
 	# 3.) Get Current Value at Index
 	current_in_circle = redis_connection.lindex( list_key , circular_list_index )
-	current_in_circle = str( current_in_circle , 'utf-8' )
+	if type( current_in_circle ) != str:
+		current_in_circle = str( current_in_circle , 'utf-8' )
 	return current_in_circle
 
 def previous( redis_connection , list_key ):
@@ -46,7 +47,8 @@ def previous( redis_connection , list_key ):
 		redis_connection.set( list_key_index , circular_list_index )
 
 	previous_in_circle = redis_connection.lindex( list_key , circular_list_index )
-	previous_in_circle = str( previous_in_circle , 'utf-8' )
+	if type( previous_in_circle ) != str:
+		previous_in_circle = str( previous_in_circle , 'utf-8' )
 	return previous_in_circle
 
 def next( redis_connection , list_key ):
@@ -75,5 +77,6 @@ def next( redis_connection , list_key ):
 		redis_connection.set( list_key_index , '0' )
 
 	next_in_circle = redis_connection.lindex( list_key , circular_list_index )
-	next_in_circle = str( next_in_circle , 'utf-8' )
-	return next_in_circle
+	if type( next_in_circle ) != str:
+		next_in_circle = str( next_in_circle , 'utf-8' )
+	return next_in_circle
\ No newline at end of file
